import React from 'react';
import { SVG } from 'primeobjects-ui-web-basic';
import { isNonEmptyString } from 'primeobjects-helper-util';
import { BubbleMenu } from '@tiptap/react';
var HtmlEditorFloatEditToolbar = function (props) {
    var editor = props.editor, hideH1 = props.hideH1, hideH2 = props.hideH2, hideH3 = props.hideH3, hideH4 = props.hideH4, supportSourceCode = props.supportSourceCode;
    var onChangeHeader = function (level) {
        editor.chain().focus().toggleHeading({ level: level }).run();
    };
    var onClickLink = function () {
        var hasLink = editor.isActive('link');
        if (hasLink) {
            editor.chain().focus().toggleLink().run();
        }
        else {
            var url = window.prompt('URL', editor.getAttributes('link').href);
            if (!isNonEmptyString(url))
                return;
            editor
                .chain()
                .focus()
                .extendMarkRange('link')
                .setLink({ href: url })
                .run();
        }
    };
    return React.createElement(BubbleMenu, { editor: editor, className: "menu-wrapper" },
        React.createElement("div", { className: "menu" },
            !hideH1 && React.createElement("div", { onClick: function () { return onChangeHeader(1); }, className: "menu-text ".concat(editor.isActive('heading', { level: 1 }) ? 'active' : '') }, "H1"),
            !hideH2 && React.createElement("div", { onClick: function () { return onChangeHeader(2); }, className: "menu-text ".concat(editor.isActive('heading', { level: 2 }) ? 'active' : '') }, "H2"),
            !hideH3 && React.createElement("div", { onClick: function () { return onChangeHeader(3); }, className: "menu-text ".concat(editor.isActive('heading', { level: 3 }) ? 'active' : '') }, "H3"),
            !hideH4 && React.createElement("div", { onClick: function () { return onChangeHeader(4); }, className: "menu-text ".concat(editor.isActive('heading', { level: 4 }) ? 'active' : '') }, "H4"),
            React.createElement("div", { className: "menu-sp" }),
            React.createElement("div", { onClick: function () { return editor.chain().focus().toggleBold().run(); }, className: "menu-text menu-text-bold ".concat(editor.isActive('bold') ? 'active' : '') }, "B"),
            React.createElement("div", { onClick: function () { return editor.chain().focus().toggleItalic().run(); }, className: "menu-text menu-text-italic ".concat(editor.isActive('italic') ? 'active' : '') }, "I"),
            React.createElement("div", { onClick: function () { return editor.chain().focus().toggleStrike().run(); }, className: "menu-text menu-text-strikethrough ".concat(editor.isActive('strike') ? 'active' : '') }, "T"),
            React.createElement("div", { className: "menu-sp" }),
            React.createElement(SVG, { src: "/icons/platform/material-bullet-list.svg", onClick: function () { return editor.chain().focus().toggleBulletList().run(); }, className: "menu-icon ".concat(editor.isActive('bulletList') ? 'active' : '') }),
            React.createElement(SVG, { src: "/icons/platform/material-numbered-list.svg", onClick: function () { return editor.chain().focus().toggleOrderedList().run(); }, className: "menu-icon ".concat(editor.isActive('orderedList') ? 'active' : '') }),
            React.createElement("div", { className: "menu-sp" }),
            supportSourceCode && React.createElement(SVG, { src: "/icons/source-code.svg", onClick: function () { return editor.chain().focus().toggleCodeBlock().run(); }, className: "menu-icon ".concat(editor.isActive('codeBlock') ? 'active' : '') }),
            React.createElement(SVG, { src: "/icons/platform/material-get-quote.svg", onClick: function () { return editor.chain().focus().toggleBlockquote().run(); }, className: "menu-icon ".concat(editor.isActive('blockquote') ? 'active' : '') }),
            React.createElement(SVG, { src: "/icons/platform/material-link.svg", onClick: onClickLink, className: "menu-icon ".concat(editor.isActive('link') ? 'active' : '') })));
};
export default HtmlEditorFloatEditToolbar;
